# Neurometa

## Installation

Most users don't need to install `neurometa` as they can just grab the output from the backups folder.

```shell
pip install neurometa
```

## Content

### Human brain structure tree
Map-typed tree from [list of regions in the human brain](https://en.wikipedia.org/wiki/List_of_regions_in_the_human_brain).

### Model organism

Map from [list of model organisms](https://en.wikipedia.org/wiki/List_of_model_organisms): Model organism to description. The user will most likely use parse and only use the keys

### Neurotransmitter

Map from table in Wikipedia [article](https://en.wikipedia.org/wiki/Neurotransmitter): Full neurotransmitter name to an `array` that stores most commonly used aliases and abbreviations. 
